@@ -93,49 +93,52 @@ class TestImageUploadManager(base.TestCase):
                                     key=operator.itemgetter('imagename'))
         self.assertEqual(sorted_expected_data, sorted_parsed_data)
 
-    @mock.patch('netifaces.ifaddresses')
-    @mock.patch('netifaces.interfaces')
-    def test_get_undercloud_registry(self, mock_interfaces, mock_addresses):
-        mock_interfaces.return_value = ['lo', 'eth0']
-        self.assertEqual(
-            'localhost:8787',
-            image_uploader.get_undercloud_registry()
-        )
+    @mock.patch('subprocess.Popen', autospec=True)
+    @mock.patch('socket.gethostname', return_value='uc.somedomain')
+    def test_get_undercloud_registry_ipv4(self, mock_gethostname,
+                                          mock_popen):
+        mock_process = mock.Mock()
+        mock_process.communicate.return_value = (
+            '192.0.2.1 uc.ctlplane.localdomain uc.ctlplane', '')
+        mock_process.returncode = 0
+        mock_popen.return_value = mock_process
+        self.assertEqual('uc.ctlplane.localdomain:8787',
+                         image_uploader.get_undercloud_registry())
 
-        mock_interfaces.return_value = ['lo', 'eth0', 'br-ctlplane']
-        mock_addresses.return_value = {
-            2: [{'addr': '192.0.2.0'}]
-        }
-        self.assertEqual(
-            '192.0.2.0:8787',
-            image_uploader.get_undercloud_registry()
-        )
+    @mock.patch('subprocess.Popen', autospec=True)
+    @mock.patch('socket.gethostname', return_value='uc.somedomain')
+    def test_get_undercloud_registry_ipv6(self, mock_gethostname,
+                                          mock_popen):
+        mock_process = mock.Mock()
+        mock_process.communicate.return_value = (
+            'fd12::1 uc.ctlplane.localdomain uc.ctlplane', '')
+        mock_process.returncode = 0
+        mock_popen.return_value = mock_process
+        self.assertEqual('uc.ctlplane.localdomain:8787',
+                         image_uploader.get_undercloud_registry())
 
-    @mock.patch('netifaces.ifaddresses')
-    @mock.patch('netifaces.interfaces')
-    @mock.patch('netifaces.AF_INET6', 10)
-    def test_get_undercloud_registry_ipv6(self, mock_interfaces,
-                                          mock_addresses):
+    @mock.patch('subprocess.Popen', autospec=True)
+    @mock.patch('socket.gethostname', return_value='undercloud.somedomain')
+    def test_get_undercloud_registry_no_etc_hosts(self, mock_gethostname,
+                                                  mock_popen):
+        mock_process = mock.Mock()
+        mock_process.communicate.return_value = ('', '')
+        mock_process.returncode = 2
+        mock_popen.return_value = mock_process
+        self.assertRaises(ImageUploaderException,
+                          image_uploader.get_undercloud_registry)
 
-        mock_interfaces.return_value = ['lo', 'eth0', 'br-ctlplane']
-        mock_addresses.return_value = {
-            10: [{'addr': 'fd12:3456:789a:1::1'}]
-        }
-        self.assertEqual(
-            '[fd12:3456:789a:1::1]:8787',
-            image_uploader.get_undercloud_registry()
-        )
-
-    @mock.patch('netifaces.ifaddresses')
-    @mock.patch('netifaces.interfaces')
-    def test_get_push_destination(self, mock_interfaces, mock_addresses):
-        mock_interfaces.return_value = ['lo', 'eth0', 'br-ctlplane']
-        mock_addresses.return_value = {
-            2: [{'addr': '192.0.2.0'}]
-        }
+    @mock.patch('subprocess.Popen', autospec=True)
+    @mock.patch('socket.gethostname', return_value='undercloud.somedomain')
+    def test_get_push_destination(self, mock_gethostname, mock_popen):
+        mock_process = mock.Mock()
+        mock_process.communicate.return_value = (
+            'fd12::1 uc.ctlplane.localdomain uc.ctlplane', '')
+        mock_process.returncode = 0
+        mock_popen.return_value = mock_process
         manager = image_uploader.ImageUploadManager(self.filelist)
         self.assertEqual(
-            '192.0.2.0:8787',
+            'uc.ctlplane.localdomain:8787',
             manager.get_push_destination({})
         )
         self.assertEqual(
@@ -144,15 +147,15 @@ class TestImageUploadManager(base.TestCase):
                                           '192.0.2.1:8787'})
         )
         self.assertEqual(
-            '192.0.2.0:8787',
+            'uc.ctlplane.localdomain:8787',
             manager.get_push_destination({'push_destination': False})
         )
         self.assertEqual(
-            '192.0.2.0:8787',
+            'uc.ctlplane.localdomain:8787',
             manager.get_push_destination({'push_destination': True})
         )
         self.assertEqual(
-            '192.0.2.0:8787',
+            'uc.ctlplane.localdomain:8787',
             manager.get_push_destination({'push_destination': None})
         )
 
@@ -479,11 +482,13 @@ class TestBaseImageUploader(base.TestCase):
 
     @mock.patch('concurrent.futures.ThreadPoolExecutor')
     def test_discover_image_tags(self, mock_pool):
-        mock_pool.return_value.map.return_value = (
+        mock_map = mock.Mock()
+        mock_map.return_value = (
             ('docker.io/t/foo', 'a'),
             ('docker.io/t/bar', 'b'),
             ('docker.io/t/baz', 'c')
         )
+        mock_pool.return_value.__enter__.return_value.map = mock_map
         images = [
             'docker.io/t/foo',
             'docker.io/t/bar',
@@ -497,7 +502,7 @@ class TestBaseImageUploader(base.TestCase):
             },
             self.uploader.discover_image_tags(images, 'rdo_release')
         )
-        mock_pool.return_value.map.assert_called_once_with(
+        mock_map.assert_called_once_with(
             image_uploader.discover_tag_from_inspect,
             [
                 (self.uploader, 'docker.io/t/foo', 'rdo_release'),
@@ -832,12 +837,14 @@ class TestBaseImageUploader(base.TestCase):
 
     @mock.patch('concurrent.futures.ThreadPoolExecutor')
     def test_list(self, mock_pool):
-        mock_pool.return_value.map.return_value = (
+        mock_map = mock.Mock()
+        mock_map.return_value = (
             ('localhost:8787/t/foo', ['a']),
             ('localhost:8787/t/bar', ['b']),
             ('localhost:8787/t/baz', ['c', 'd']),
             ('localhost:8787/t/bink', [])
         )
+        mock_pool.return_value.__enter__.return_value.map = mock_map
         session = mock.Mock()
         response = mock.Mock()
         response.status_code = 200
@@ -854,7 +861,7 @@ class TestBaseImageUploader(base.TestCase):
             ],
             self.uploader.list('localhost:8787', session=session)
         )
-        mock_pool.return_value.map.assert_called_once_with(
+        mock_map.assert_called_once_with(
             image_uploader.tags_for_image,
             [
                 (self.uploader, 'localhost:8787/t/foo', session),
@@ -863,14 +870,12 @@ class TestBaseImageUploader(base.TestCase):
                 (self.uploader, 'localhost:8787/t/bink', session)
             ])
 
-    @mock.patch('concurrent.futures.ThreadPoolExecutor')
-    def test_list_404(self, mock_pool):
+    def test_list_404(self):
         # setup bits
         session = mock.Mock()
         response = mock.Mock()
         response.status_code = 404
         session.get.return_value = response
-        mock_pool.return_value.map.return_value = ()
         # execute function
         return_val = self.uploader.list('localhost:8787', session=session)
         # check status of things
@@ -1018,7 +1023,8 @@ class TestSkopeoImageUploader(base.TestCase):
                     'container_build_tool': 'buildah'
                 }
             }],
-            'hosts': 'localhost'
+            'hosts': 'localhost',
+            'gather_facts': 'no'
         }]
 
         # test response for a partial cleanup
@@ -1312,7 +1318,8 @@ class TestPythonImageUploader(base.TestCase):
             source_session=source_session,
             target_session=target_session,
             source_layers=['sha256:aaa', 'sha256:bbb', 'sha256:ccc'],
-            multi_arch=False
+            multi_arch=False,
+            lock=None
         )
 
     @mock.patch('tripleo_common.image.image_uploader.'
@@ -1546,7 +1553,8 @@ class TestPythonImageUploader(base.TestCase):
             source_session=source_session,
             target_session=target_session,
             source_layers=['sha256:aaa', 'sha256:bbb', 'sha256:ccc'],
-            multi_arch=False
+            multi_arch=False,
+            lock=None
         )
 
     @mock.patch('tripleo_common.image.image_uploader.'
@@ -1677,7 +1685,8 @@ class TestPythonImageUploader(base.TestCase):
             source_session=source_session,
             target_session=target_session,
             source_layers=['sha256:aaa', 'sha256:bbb', 'sha256:ccc'],
-            multi_arch=False
+            multi_arch=False,
+            lock=None
         )
         _copy_registry_to_local.assert_called_once_with(unmodified_target_url)
         run_modify_playbook.assert_called_once_with(
